// SPDX-License-Identifier: GPL-2.0
/*
 * Mitwell RSQ10 platform driver
 *
 * Copyright (c) TTTECH Industrial AUtomation AG, 2024
 *
 * Author: Helmut Buchsbaum <helmut.buchsbaum@tttech-industrial.com>
 */
#ifndef __PLATFORM_DATA_X86_RSQ10_H
#define __PLATFORM_DATA_X86_RSQ10_H

#include <linux/types.h>

enum rsq10_type {
	RSQ10,
	RSQ10_TT
};
struct rsq10_platform {
	u16 io_base;
	u16 led_gpio_offset;
	enum rsq10_type type;
};

/*
 * Mitwell RSQ10 uses an IT5121 I/O chip to control the LEDs via GPIOx_EC
 * (x=0-6). According to Mitwell's userspace library, the GPIO port
 * is located at 0xe300 with offset 0x2c and provides an 8bit port with
 * the LEDs on GPIO0-6. GPIO7 is used elsewhere.
 */
#define RSQ10_IT5121_BASE	0xe300
#define RSQ10_IT5121_LED_GPIO	0x2c

#endif /* __PLATFORM_DATA_X86_RSQ10_H */
